@@ -1,4 +1,4 @@
-$(document).ready(function () {
+jQuery(document).ready(function ($) {
     $(".collapse").on("shown.bs.collapse", function () {
         localStorage.setItem("coll_" + this.id, true);
     });
@@ -10,8 +10,7 @@ $(document).ready(function () {
     $(".collapse").each(function () {
         if (localStorage.getItem("coll_" + this.id) === "true") {
             $(this).collapse("show");
-        }
-        else {
+        } else {
             $(this).collapse("hide");
         }
     });
@@ -25,19 +24,18 @@ $(document).ready(function () {
         }
     }
 
-    $('[id*="task"]').on('click', function() {
-        if(this.open) {
+    $('[id*="task"]').on('click', function () {
+        if (this.open) {
             localStorage.removeItem(page + "activity_coll_" + this.id);
         } else {
             localStorage.setItem(page + "activity_coll_" + this.id, true);
         }
     })
 
-    $('[id*="task"]').each(function() {
+    $('[id*="task"]').each(function () {
         if (localStorage.getItem(page + "activity_coll_" + this.id) === "true") {
             $(this).attr('open', true);
-        }
-        else {
+        } else {
             $(this).attr('open', false);
         }
     })
